@@ -26,8 +26,8 @@ from google.cloud.firestore_admin_v1.gapic import firestore_admin_client
 
 if sys.version_info[:2] == (2, 7):
     message = (
-        "A future version of this library will drop support for Python 2.7."
-        "More details about Python 2 support for Google Cloud Client Libraries"
+        "A future version of this library will drop support for Python 2.7. "
+        "More details about Python 2 support for Google Cloud Client Libraries "
         "can be found at https://cloud.google.com/python/docs/python2-sunset/"
     )
     warnings.warn(message, DeprecationWarning)
@@ -38,4 +38,8 @@ class FirestoreAdminClient(firestore_admin_client.FirestoreAdminClient):
     enums = enums
 
 
-__all__ = ("enums", "types", "FirestoreAdminClient")
+__all__ = (
+    "enums",
+    "types",
+    "FirestoreAdminClient",
+)
