@@ -20,7 +20,6 @@ a more common way to create a query than direct usage of the constructor.
 """
 import copy
 import math
-import warnings
 
 from google.protobuf import wrappers_pb2
 import six
@@ -86,6 +85,8 @@ class Query(object):
             The "order by" entries to use in the query.
         limit (Optional[int]):
             The maximum number of documents the query is allowed to return.
+        limit_to_last (Optional[bool]):
+            Denotes whether a provided limit is applied to the end of the result set.
         offset (Optional[int]):
             The number of results to skip.
         start_at (Optional[Tuple[dict, bool]]):
@@ -134,6 +135,7 @@ class Query(object):
         field_filters=(),
         orders=(),
         limit=None,
+        limit_to_last=False,
         offset=None,
         start_at=None,
         end_at=None,
@@ -144,6 +146,7 @@ class Query(object):
         self._field_filters = field_filters
         self._orders = orders
         self._limit = limit
+        self._limit_to_last = limit_to_last
         self._offset = offset
         self._start_at = start_at
         self._end_at = end_at
@@ -158,6 +161,7 @@ class Query(object):
             and self._field_filters == other._field_filters
             and self._orders == other._orders
             and self._limit == other._limit
+            and self._limit_to_last == other._limit_to_last
             and self._offset == other._offset
             and self._start_at == other._start_at
             and self._end_at == other._end_at
@@ -212,6 +216,7 @@ class Query(object):
             field_filters=self._field_filters,
             orders=self._orders,
             limit=self._limit,
+            limit_to_last=self._limit_to_last,
             offset=self._offset,
             start_at=self._start_at,
             end_at=self._end_at,
@@ -281,6 +286,7 @@ class Query(object):
             field_filters=new_filters,
             orders=self._orders,
             limit=self._limit,
+            limit_to_last=self._limit_to_last,
             offset=self._offset,
             start_at=self._start_at,
             end_at=self._end_at,
@@ -333,6 +339,7 @@ class Query(object):
             field_filters=self._field_filters,
             orders=new_orders,
             limit=self._limit,
+            limit_to_last=self._limit_to_last,
             offset=self._offset,
             start_at=self._start_at,
             end_at=self._end_at,
@@ -340,9 +347,14 @@ class Query(object):
         )
 
     def limit(self, count):
-        """Limit a query to return a fixed number of results.
+        """Limit a query to return at most `count` matching results.
 
-        If the current query already has a limit set, this will overwrite it.
+        If the current query already has a `limit` set, this will override it.
+
+        .. note::
+
+           `limit` and `limit_to_last` are mutually exclusive.
+           Setting `limit` will drop previously set `limit_to_last`.
 
         Args:
             count (int): Maximum number of documents to return that match
@@ -359,6 +371,40 @@ class Query(object):
             field_filters=self._field_filters,
             orders=self._orders,
             limit=count,
+            limit_to_last=False,
+            offset=self._offset,
+            start_at=self._start_at,
+            end_at=self._end_at,
+            all_descendants=self._all_descendants,
+        )
+
+    def limit_to_last(self, count):
+        """Limit a query to return the last `count` matching results.
+
+        If the current query already has a `limit_to_last`
+        set, this will override it.
+
+        .. note::
+
+           `limit` and `limit_to_last` are mutually exclusive.
+           Setting `limit_to_last` will drop previously set `limit`.
+
+        Args:
+            count (int): Maximum number of documents to return that match
+                the query.
+
+        Returns:
+            :class:`~google.cloud.firestore_v1.query.Query`:
+            A limited query. Acts as a copy of the current query, modified
+            with the newly added "limit" filter.
+        """
+        return self.__class__(
+            self._parent,
+            projection=self._projection,
+            field_filters=self._field_filters,
+            orders=self._orders,
+            limit=count,
+            limit_to_last=True,
             offset=self._offset,
             start_at=self._start_at,
             end_at=self._end_at,
@@ -386,13 +432,14 @@ class Query(object):
             field_filters=self._field_filters,
             orders=self._orders,
             limit=self._limit,
+            limit_to_last=self._limit_to_last,
             offset=num_to_skip,
             start_at=self._start_at,
             end_at=self._end_at,
             all_descendants=self._all_descendants,
         )
 
-    def _check_snapshot(self, document_fields):
+    def _check_snapshot(self, document_snapshot):
         """Validate local snapshots for non-collection-group queries.
 
         Raises:
@@ -402,26 +449,26 @@ class Query(object):
         if self._all_descendants:
             return
 
-        if document_fields.reference._path[:-1] != self._parent._path:
+        if document_snapshot.reference._path[:-1] != self._parent._path:
             raise ValueError("Cannot use snapshot from another collection as a cursor.")
 
-    def _cursor_helper(self, document_fields, before, start):
+    def _cursor_helper(self, document_fields_or_snapshot, before, start):
         """Set values to be used for a ``start_at`` or ``end_at`` cursor.
 
         The values will later be used in a query protobuf.
 
-        When the query is sent to the server, the ``document_fields`` will
+        When the query is sent to the server, the ``document_fields_or_snapshot`` will
         be used in the order given by fields set by
         :meth:`~google.cloud.firestore_v1.query.Query.order_by`.
 
         Args:
-            document_fields
+            document_fields_or_snapshot
                 (Union[:class:`~google.cloud.firestore_v1.document.DocumentSnapshot`, dict, list, tuple]):
                 a document snapshot or a dictionary/list/tuple of fields
                 representing a query results cursor. A cursor is a collection
                 of values that represent a position in a query result set.
             before (bool): Flag indicating if the document in
-                ``document_fields`` should (:data:`False`) or
+                ``document_fields_or_snapshot`` should (:data:`False`) or
                 shouldn't (:data:`True`) be included in the result set.
             start (Optional[bool]): determines if the cursor is a ``start_at``
                 cursor (:data:`True`) or an ``end_at`` cursor (:data:`False`).
@@ -431,15 +478,15 @@ class Query(object):
             A query with cursor. Acts as a copy of the current query, modified
             with the newly added "start at" cursor.
         """
-        if isinstance(document_fields, tuple):
-            document_fields = list(document_fields)
-        elif isinstance(document_fields, document.DocumentSnapshot):
-            self._check_snapshot(document_fields)
+        if isinstance(document_fields_or_snapshot, tuple):
+            document_fields_or_snapshot = list(document_fields_or_snapshot)
+        elif isinstance(document_fields_or_snapshot, document.DocumentSnapshot):
+            self._check_snapshot(document_fields_or_snapshot)
         else:
             # NOTE: We copy so that the caller can't modify after calling.
-            document_fields = copy.deepcopy(document_fields)
+            document_fields_or_snapshot = copy.deepcopy(document_fields_or_snapshot)
 
-        cursor_pair = document_fields, before
+        cursor_pair = document_fields_or_snapshot, before
         query_kwargs = {
             "projection": self._projection,
             "field_filters": self._field_filters,
@@ -457,23 +504,23 @@ class Query(object):
 
         return self.__class__(self._parent, **query_kwargs)
 
-    def start_at(self, document_fields):
+    def start_at(self, document_fields_or_snapshot):
         """Start query results at a particular document value.
 
         The result set will **include** the document specified by
-        ``document_fields``.
+        ``document_fields_or_snapshot``.
 
         If the current query already has specified a start cursor -- either
         via this method or
         :meth:`~google.cloud.firestore_v1.query.Query.start_after` -- this
         will overwrite it.
 
-        When the query is sent to the server, the ``document_fields`` will
+        When the query is sent to the server, the ``document_fields_or_snapshot`` will
         be used in the order given by fields set by
         :meth:`~google.cloud.firestore_v1.query.Query.order_by`.
 
         Args:
-            document_fields
+            document_fields_or_snapshot
                 (Union[:class:`~google.cloud.firestore_v1.document.DocumentSnapshot`, dict, list, tuple]):
                 a document snapshot or a dictionary/list/tuple of fields
                 representing a query results cursor. A cursor is a collection
@@ -485,25 +532,25 @@ class Query(object):
             a copy of the current query, modified with the newly added
             "start at" cursor.
         """
-        return self._cursor_helper(document_fields, before=True, start=True)
+        return self._cursor_helper(document_fields_or_snapshot, before=True, start=True)
 
-    def start_after(self, document_fields):
+    def start_after(self, document_fields_or_snapshot):
         """Start query results after a particular document value.
 
         The result set will **exclude** the document specified by
-        ``document_fields``.
+        ``document_fields_or_snapshot``.
 
         If the current query already has specified a start cursor -- either
         via this method or
         :meth:`~google.cloud.firestore_v1.query.Query.start_at` -- this will
         overwrite it.
 
-        When the query is sent to the server, the ``document_fields`` will
+        When the query is sent to the server, the ``document_fields_or_snapshot`` will
         be used in the order given by fields set by
         :meth:`~google.cloud.firestore_v1.query.Query.order_by`.
 
         Args:
-            document_fields
+            document_fields_or_snapshot
                 (Union[:class:`~google.cloud.firestore_v1.document.DocumentSnapshot`, dict, list, tuple]):
                 a document snapshot or a dictionary/list/tuple of fields
                 representing a query results cursor. A cursor is a collection
@@ -514,25 +561,27 @@ class Query(object):
             A query with cursor. Acts as a copy of the current query, modified
             with the newly added "start after" cursor.
         """
-        return self._cursor_helper(document_fields, before=False, start=True)
+        return self._cursor_helper(
+            document_fields_or_snapshot, before=False, start=True
+        )
 
-    def end_before(self, document_fields):
+    def end_before(self, document_fields_or_snapshot):
         """End query results before a particular document value.
 
         The result set will **exclude** the document specified by
-        ``document_fields``.
+        ``document_fields_or_snapshot``.
 
         If the current query already has specified an end cursor -- either
         via this method or
         :meth:`~google.cloud.firestore_v1.query.Query.end_at` -- this will
         overwrite it.
 
-        When the query is sent to the server, the ``document_fields`` will
+        When the query is sent to the server, the ``document_fields_or_snapshot`` will
         be used in the order given by fields set by
         :meth:`~google.cloud.firestore_v1.query.Query.order_by`.
 
         Args:
-            document_fields
+            document_fields_or_snapshot
                 (Union[:class:`~google.cloud.firestore_v1.document.DocumentSnapshot`, dict, list, tuple]):
                 a document snapshot or a dictionary/list/tuple of fields
                 representing a query results cursor. A cursor is a collection
@@ -543,25 +592,27 @@ class Query(object):
             A query with cursor. Acts as a copy of the current query, modified
             with the newly added "end before" cursor.
         """
-        return self._cursor_helper(document_fields, before=True, start=False)
+        return self._cursor_helper(
+            document_fields_or_snapshot, before=True, start=False
+        )
 
-    def end_at(self, document_fields):
+    def end_at(self, document_fields_or_snapshot):
         """End query results at a particular document value.
 
         The result set will **include** the document specified by
-        ``document_fields``.
+        ``document_fields_or_snapshot``.
 
         If the current query already has specified an end cursor -- either
         via this method or
         :meth:`~google.cloud.firestore_v1.query.Query.end_before` -- this will
         overwrite it.
 
-        When the query is sent to the server, the ``document_fields`` will
+        When the query is sent to the server, the ``document_fields_or_snapshot`` will
         be used in the order given by fields set by
         :meth:`~google.cloud.firestore_v1.query.Query.order_by`.
 
         Args:
-            document_fields
+            document_fields_or_snapshot
                 (Union[:class:`~google.cloud.firestore_v1.document.DocumentSnapshot`, dict, list, tuple]):
                 a document snapshot or a dictionary/list/tuple of fields
                 representing a query results cursor. A cursor is a collection
@@ -572,7 +623,9 @@ class Query(object):
             A query with cursor. Acts as a copy of the current query, modified
             with the newly added "end at" cursor.
         """
-        return self._cursor_helper(document_fields, before=False, start=False)
+        return self._cursor_helper(
+            document_fields_or_snapshot, before=False, start=False
+        )
 
     def _filters_pb(self):
         """Convert all the filters into a single generic Filter protobuf.
@@ -729,13 +782,42 @@ class Query(object):
         return query_pb2.StructuredQuery(**query_kwargs)
 
     def get(self, transaction=None):
-        """Deprecated alias for :meth:`stream`."""
-        warnings.warn(
-            "'Query.get' is deprecated:  please use 'Query.stream' instead.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return self.stream(transaction=transaction)
+        """Read the documents in the collection that match this query.
+
+        This sends a ``RunQuery`` RPC and returns a list of documents
+        returned in the stream of ``RunQueryResponse`` messages.
+
+        Args:
+            transaction
+                (Optional[:class:`~google.cloud.firestore_v1.transaction.Transaction`]):
+                An existing transaction that this query will run in.
+
+        If a ``transaction`` is used and it already has write operations
+        added, this method cannot be used (i.e. read-after-write is not
+        allowed).
+
+        Returns:
+            list: The documents in the collection that match this query.
+        """
+        is_limited_to_last = self._limit_to_last
+
+        if self._limit_to_last:
+            # In order to fetch up to `self._limit` results from the end of the
+            # query flip the defined ordering on the query to start from the
+            # end, retrieving up to `self._limit` results from the backend.
+            for order in self._orders:
+                order.direction = _enum_from_direction(
+                    self.DESCENDING
+                    if order.direction == self.ASCENDING
+                    else self.ASCENDING
+                )
+            self._limit_to_last = False
+
+        result = self.stream(transaction=transaction)
+        if is_limited_to_last:
+            result = reversed(list(result))
+
+        return list(result)
 
     def stream(self, transaction=None):
         """Read the documents in the collection that match this query.
@@ -764,6 +846,11 @@ class Query(object):
             :class:`~google.cloud.firestore_v1.document.DocumentSnapshot`:
             The next document that fulfills the query.
         """
+        if self._limit_to_last:
+            raise ValueError(
+                "Query results for queries that include limit_to_last() "
+                "constraints cannot be streamed. Use Query.get() instead."
+            )
         parent_path, expected_prefix = self._parent._parent_info()
         response_iterator = self._client._firestore_api.run_query(
             parent_path,
@@ -791,7 +878,8 @@ class Query(object):
         provided callback is run on the snapshot of the documents.
 
         Args:
-            callback(Callable[[:class:`~google.cloud.firestore.query.QuerySnapshot`], NoneType]):
+            callback (Callable[List[:class:`~google.cloud.firestore_v1.query.QuerySnapshot`], \
+            List[:class:`~google.cloud.firestore_v1.watch.DocumentChange`], datetime.datetime], NoneType):
                 a callback to run when a change occurs.
 
         Example:
