@@ -20,9 +20,9 @@ import mock
 import pytest
 
 from google.cloud.firestore_v1.gapic import firestore_client
-from google.cloud.firestore_v1.proto import common_pb2
 from google.cloud.firestore_v1.proto import document_pb2
 from google.cloud.firestore_v1.proto import firestore_pb2
+from google.cloud.firestore_v1.proto import query_pb2
 from google.protobuf import empty_pb2
 
 
@@ -85,9 +85,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        name = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        name = "name3373707"
 
         response = client.get_document(name)
         assert expected_response == response
@@ -106,9 +104,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        name = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        name = "name3373707"
 
         with pytest.raises(CustomException):
             client.get_document(name)
@@ -129,9 +125,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
         collection_id = "collectionId-821242276"
 
         paged_list_response = client.list_documents(parent, collection_id)
@@ -155,9 +149,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
         collection_id = "collectionId-821242276"
 
         paged_list_response = client.list_documents(parent, collection_id)
@@ -178,21 +170,18 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
         collection_id = "collectionId-821242276"
-        document_id = "documentId506676927"
         document = {}
 
-        response = client.create_document(parent, collection_id, document_id, document)
+        response = client.create_document(parent, collection_id, "documentid", document)
         assert expected_response == response
 
         assert len(channel.requests) == 1
         expected_request = firestore_pb2.CreateDocumentRequest(
             parent=parent,
             collection_id=collection_id,
-            document_id=document_id,
+            document_id="documentid",
             document=document,
         )
         actual_request = channel.requests[0][1]
@@ -207,15 +196,12 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
         collection_id = "collectionId-821242276"
-        document_id = "documentId506676927"
         document = {}
 
         with pytest.raises(CustomException):
-            client.create_document(parent, collection_id, document_id, document)
+            client.create_document(parent, collection_id, "documentid", document)
 
     def test_update_document(self):
         # Setup Expected Response
@@ -232,15 +218,12 @@ class TestFirestoreClient(object):
 
         # Setup Request
         document = {}
-        update_mask = {}
 
-        response = client.update_document(document, update_mask)
+        response = client.update_document(document)
         assert expected_response == response
 
         assert len(channel.requests) == 1
-        expected_request = firestore_pb2.UpdateDocumentRequest(
-            document=document, update_mask=update_mask
-        )
+        expected_request = firestore_pb2.UpdateDocumentRequest(document=document)
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
@@ -254,10 +237,9 @@ class TestFirestoreClient(object):
 
         # Setup request
         document = {}
-        update_mask = {}
 
         with pytest.raises(CustomException):
-            client.update_document(document, update_mask)
+            client.update_document(document)
 
     def test_delete_document(self):
         channel = ChannelStub()
@@ -267,9 +249,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        name = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        name = "name3373707"
 
         client.delete_document(name)
 
@@ -287,9 +267,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        name = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        name = "name3373707"
 
         with pytest.raises(CustomException):
             client.delete_document(name)
@@ -309,18 +287,15 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
-        documents = []
+        database = "database1789464955"
 
-        response = client.batch_get_documents(database, documents)
+        response = client.batch_get_documents(database)
         resources = list(response)
         assert len(resources) == 1
         assert expected_response == resources[0]
 
         assert len(channel.requests) == 1
-        expected_request = firestore_pb2.BatchGetDocumentsRequest(
-            database=database, documents=documents
-        )
+        expected_request = firestore_pb2.BatchGetDocumentsRequest(database=database)
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
@@ -333,11 +308,47 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
-        documents = []
+        database = "database1789464955"
 
         with pytest.raises(CustomException):
-            client.batch_get_documents(database, documents)
+            client.batch_get_documents(database)
+
+    def test_batch_write(self):
+        # Setup Expected Response
+        expected_response = {}
+        expected_response = firestore_pb2.BatchWriteResponse(**expected_response)
+
+        # Mock the API response
+        channel = ChannelStub(responses=[expected_response])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup Request
+        database = "database1789464955"
+
+        response = client.batch_write(database)
+        assert expected_response == response
+
+        assert len(channel.requests) == 1
+        expected_request = firestore_pb2.BatchWriteRequest(database=database)
+        actual_request = channel.requests[0][1]
+        assert expected_request == actual_request
+
+    def test_batch_write_exception(self):
+        # Mock the API response
+        channel = ChannelStub(responses=[CustomException()])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup request
+        database = "database1789464955"
+
+        with pytest.raises(CustomException):
+            client.batch_write(database)
 
     def test_begin_transaction(self):
         # Setup Expected Response
@@ -353,7 +364,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
 
         response = client.begin_transaction(database)
         assert expected_response == response
@@ -372,7 +383,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
 
         with pytest.raises(CustomException):
             client.begin_transaction(database)
@@ -390,14 +401,13 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
-        writes = []
+        database = "database1789464955"
 
-        response = client.commit(database, writes)
+        response = client.commit(database)
         assert expected_response == response
 
         assert len(channel.requests) == 1
-        expected_request = firestore_pb2.CommitRequest(database=database, writes=writes)
+        expected_request = firestore_pb2.CommitRequest(database=database)
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
@@ -410,11 +420,10 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
-        writes = []
+        database = "database1789464955"
 
         with pytest.raises(CustomException):
-            client.commit(database, writes)
+            client.commit(database)
 
     def test_rollback(self):
         channel = ChannelStub()
@@ -424,7 +433,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         transaction = b"-34"
 
         client.rollback(database, transaction)
@@ -445,7 +454,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         transaction = b"-34"
 
         with pytest.raises(CustomException):
@@ -469,9 +478,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
 
         response = client.run_query(parent)
         resources = list(response)
@@ -492,9 +499,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
 
         with pytest.raises(CustomException):
             client.run_query(parent)
@@ -514,7 +519,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         request = {"database": database}
         request = firestore_pb2.WriteRequest(**request)
         requests = [request]
@@ -539,7 +544,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         request = {"database": database}
 
         request = firestore_pb2.WriteRequest(**request)
@@ -561,7 +566,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         request = {"database": database}
         request = firestore_pb2.ListenRequest(**request)
         requests = [request]
@@ -586,7 +591,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         request = {"database": database}
 
         request = firestore_pb2.ListenRequest(**request)
@@ -614,9 +619,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
 
         paged_list_response = client.list_collection_ids(parent)
         resources = list(paged_list_response)
@@ -637,10 +640,54 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
 
         paged_list_response = client.list_collection_ids(parent)
         with pytest.raises(CustomException):
             list(paged_list_response)
+
+    def test_partition_query(self):
+        # Setup Expected Response
+        next_page_token = ""
+        partitions_element = {}
+        partitions = [partitions_element]
+        expected_response = {
+            "next_page_token": next_page_token,
+            "partitions": partitions,
+        }
+        expected_response = firestore_pb2.PartitionQueryResponse(**expected_response)
+
+        # Mock the API response
+        channel = ChannelStub(responses=[expected_response])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup Request
+        parent = "parent-995424086"
+
+        paged_list_response = client.partition_query(parent)
+        resources = list(paged_list_response)
+        assert len(resources) == 1
+
+        assert expected_response.partitions[0] == resources[0]
+
+        assert len(channel.requests) == 1
+        expected_request = firestore_pb2.PartitionQueryRequest(parent=parent)
+        actual_request = channel.requests[0][1]
+        assert expected_request == actual_request
+
+    def test_partition_query_exception(self):
+        channel = ChannelStub(responses=[CustomException()])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup request
+        parent = "parent-995424086"
+
+        paged_list_response = client.partition_query(parent)
+        with pytest.raises(CustomException):
+            list(paged_list_response)
