@@ -20,7 +20,6 @@ import mock
 import pytest
 
 from google.cloud.firestore_v1beta1.gapic import firestore_client
-from google.cloud.firestore_v1beta1.proto import common_pb2
 from google.cloud.firestore_v1beta1.proto import document_pb2
 from google.cloud.firestore_v1beta1.proto import firestore_pb2
 from google.protobuf import empty_pb2
@@ -71,194 +70,6 @@ class CustomException(Exception):
 
 
 class TestFirestoreClient(object):
-    def test_get_document(self):
-        # Setup Expected Response
-        name_2 = "name2-1052831874"
-        expected_response = {"name": name_2}
-        expected_response = document_pb2.Document(**expected_response)
-
-        # Mock the API response
-        channel = ChannelStub(responses=[expected_response])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup Request
-        name = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
-
-        response = client.get_document(name)
-        assert expected_response == response
-
-        assert len(channel.requests) == 1
-        expected_request = firestore_pb2.GetDocumentRequest(name=name)
-        actual_request = channel.requests[0][1]
-        assert expected_request == actual_request
-
-    def test_get_document_exception(self):
-        # Mock the API response
-        channel = ChannelStub(responses=[CustomException()])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup request
-        name = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
-
-        with pytest.raises(CustomException):
-            client.get_document(name)
-
-    def test_list_documents(self):
-        # Setup Expected Response
-        next_page_token = ""
-        documents_element = {}
-        documents = [documents_element]
-        expected_response = {"next_page_token": next_page_token, "documents": documents}
-        expected_response = firestore_pb2.ListDocumentsResponse(**expected_response)
-
-        # Mock the API response
-        channel = ChannelStub(responses=[expected_response])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup Request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
-        collection_id = "collectionId-821242276"
-
-        paged_list_response = client.list_documents(parent, collection_id)
-        resources = list(paged_list_response)
-        assert len(resources) == 1
-
-        assert expected_response.documents[0] == resources[0]
-
-        assert len(channel.requests) == 1
-        expected_request = firestore_pb2.ListDocumentsRequest(
-            parent=parent, collection_id=collection_id
-        )
-        actual_request = channel.requests[0][1]
-        assert expected_request == actual_request
-
-    def test_list_documents_exception(self):
-        channel = ChannelStub(responses=[CustomException()])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
-        collection_id = "collectionId-821242276"
-
-        paged_list_response = client.list_documents(parent, collection_id)
-        with pytest.raises(CustomException):
-            list(paged_list_response)
-
-    def test_create_document(self):
-        # Setup Expected Response
-        name = "name3373707"
-        expected_response = {"name": name}
-        expected_response = document_pb2.Document(**expected_response)
-
-        # Mock the API response
-        channel = ChannelStub(responses=[expected_response])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup Request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
-        collection_id = "collectionId-821242276"
-        document_id = "documentId506676927"
-        document = {}
-
-        response = client.create_document(parent, collection_id, document_id, document)
-        assert expected_response == response
-
-        assert len(channel.requests) == 1
-        expected_request = firestore_pb2.CreateDocumentRequest(
-            parent=parent,
-            collection_id=collection_id,
-            document_id=document_id,
-            document=document,
-        )
-        actual_request = channel.requests[0][1]
-        assert expected_request == actual_request
-
-    def test_create_document_exception(self):
-        # Mock the API response
-        channel = ChannelStub(responses=[CustomException()])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
-        collection_id = "collectionId-821242276"
-        document_id = "documentId506676927"
-        document = {}
-
-        with pytest.raises(CustomException):
-            client.create_document(parent, collection_id, document_id, document)
-
-    def test_update_document(self):
-        # Setup Expected Response
-        name = "name3373707"
-        expected_response = {"name": name}
-        expected_response = document_pb2.Document(**expected_response)
-
-        # Mock the API response
-        channel = ChannelStub(responses=[expected_response])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup Request
-        document = {}
-        update_mask = {}
-
-        response = client.update_document(document, update_mask)
-        assert expected_response == response
-
-        assert len(channel.requests) == 1
-        expected_request = firestore_pb2.UpdateDocumentRequest(
-            document=document, update_mask=update_mask
-        )
-        actual_request = channel.requests[0][1]
-        assert expected_request == actual_request
-
-    def test_update_document_exception(self):
-        # Mock the API response
-        channel = ChannelStub(responses=[CustomException()])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup request
-        document = {}
-        update_mask = {}
-
-        with pytest.raises(CustomException):
-            client.update_document(document, update_mask)
-
     def test_delete_document(self):
         channel = ChannelStub()
         patch = mock.patch("google.api_core.grpc_helpers.create_channel")
@@ -267,9 +78,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        name = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        name = "name3373707"
 
         client.delete_document(name)
 
@@ -287,9 +96,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        name = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        name = "name3373707"
 
         with pytest.raises(CustomException):
             client.delete_document(name)
@@ -309,18 +116,15 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
-        documents = []
+        database = "database1789464955"
 
-        response = client.batch_get_documents(database, documents)
+        response = client.batch_get_documents(database)
         resources = list(response)
         assert len(resources) == 1
         assert expected_response == resources[0]
 
         assert len(channel.requests) == 1
-        expected_request = firestore_pb2.BatchGetDocumentsRequest(
-            database=database, documents=documents
-        )
+        expected_request = firestore_pb2.BatchGetDocumentsRequest(database=database)
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
@@ -333,11 +137,10 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
-        documents = []
+        database = "database1789464955"
 
         with pytest.raises(CustomException):
-            client.batch_get_documents(database, documents)
+            client.batch_get_documents(database)
 
     def test_begin_transaction(self):
         # Setup Expected Response
@@ -353,7 +156,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
 
         response = client.begin_transaction(database)
         assert expected_response == response
@@ -372,50 +175,11 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
 
         with pytest.raises(CustomException):
             client.begin_transaction(database)
 
-    def test_commit(self):
-        # Setup Expected Response
-        expected_response = {}
-        expected_response = firestore_pb2.CommitResponse(**expected_response)
-
-        # Mock the API response
-        channel = ChannelStub(responses=[expected_response])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
-        writes = []
-
-        response = client.commit(database, writes)
-        assert expected_response == response
-
-        assert len(channel.requests) == 1
-        expected_request = firestore_pb2.CommitRequest(database=database, writes=writes)
-        actual_request = channel.requests[0][1]
-        assert expected_request == actual_request
-
-    def test_commit_exception(self):
-        # Mock the API response
-        channel = ChannelStub(responses=[CustomException()])
-        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
-        with patch as create_channel:
-            create_channel.return_value = channel
-            client = firestore_client.FirestoreClient()
-
-        # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
-        writes = []
-
-        with pytest.raises(CustomException):
-            client.commit(database, writes)
-
     def test_rollback(self):
         channel = ChannelStub()
         patch = mock.patch("google.api_core.grpc_helpers.create_channel")
@@ -424,7 +188,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         transaction = b"-34"
 
         client.rollback(database, transaction)
@@ -445,7 +209,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         transaction = b"-34"
 
         with pytest.raises(CustomException):
@@ -469,9 +233,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
 
         response = client.run_query(parent)
         resources = list(response)
@@ -492,9 +254,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
 
         with pytest.raises(CustomException):
             client.run_query(parent)
@@ -514,7 +274,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         request = {"database": database}
         request = firestore_pb2.WriteRequest(**request)
         requests = [request]
@@ -539,7 +299,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         request = {"database": database}
 
         request = firestore_pb2.WriteRequest(**request)
@@ -561,7 +321,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         request = {"database": database}
         request = firestore_pb2.ListenRequest(**request)
         requests = [request]
@@ -586,7 +346,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        database = client.database_root_path("[PROJECT]", "[DATABASE]")
+        database = "database1789464955"
         request = {"database": database}
 
         request = firestore_pb2.ListenRequest(**request)
@@ -614,9 +374,7 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup Request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
 
         paged_list_response = client.list_collection_ids(parent)
         resources = list(paged_list_response)
@@ -637,10 +395,215 @@ class TestFirestoreClient(object):
             client = firestore_client.FirestoreClient()
 
         # Setup request
-        parent = client.any_path_path(
-            "[PROJECT]", "[DATABASE]", "[DOCUMENT]", "[ANY_PATH]"
-        )
+        parent = "parent-995424086"
 
         paged_list_response = client.list_collection_ids(parent)
         with pytest.raises(CustomException):
             list(paged_list_response)
+
+    def test_get_document(self):
+        # Setup Expected Response
+        name_2 = "name2-1052831874"
+        expected_response = {"name": name_2}
+        expected_response = document_pb2.Document(**expected_response)
+
+        # Mock the API response
+        channel = ChannelStub(responses=[expected_response])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup Request
+        name = "name3373707"
+
+        response = client.get_document(name)
+        assert expected_response == response
+
+        assert len(channel.requests) == 1
+        expected_request = firestore_pb2.GetDocumentRequest(name=name)
+        actual_request = channel.requests[0][1]
+        assert expected_request == actual_request
+
+    def test_get_document_exception(self):
+        # Mock the API response
+        channel = ChannelStub(responses=[CustomException()])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup request
+        name = "name3373707"
+
+        with pytest.raises(CustomException):
+            client.get_document(name)
+
+    def test_list_documents(self):
+        # Setup Expected Response
+        next_page_token = ""
+        documents_element = {}
+        documents = [documents_element]
+        expected_response = {"next_page_token": next_page_token, "documents": documents}
+        expected_response = firestore_pb2.ListDocumentsResponse(**expected_response)
+
+        # Mock the API response
+        channel = ChannelStub(responses=[expected_response])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup Request
+        parent = "parent-995424086"
+        collection_id = "collectionId-821242276"
+
+        paged_list_response = client.list_documents(parent, collection_id)
+        resources = list(paged_list_response)
+        assert len(resources) == 1
+
+        assert expected_response.documents[0] == resources[0]
+
+        assert len(channel.requests) == 1
+        expected_request = firestore_pb2.ListDocumentsRequest(
+            parent=parent, collection_id=collection_id
+        )
+        actual_request = channel.requests[0][1]
+        assert expected_request == actual_request
+
+    def test_list_documents_exception(self):
+        channel = ChannelStub(responses=[CustomException()])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup request
+        parent = "parent-995424086"
+        collection_id = "collectionId-821242276"
+
+        paged_list_response = client.list_documents(parent, collection_id)
+        with pytest.raises(CustomException):
+            list(paged_list_response)
+
+    def test_create_document(self):
+        # Setup Expected Response
+        name = "name3373707"
+        expected_response = {"name": name}
+        expected_response = document_pb2.Document(**expected_response)
+
+        # Mock the API response
+        channel = ChannelStub(responses=[expected_response])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup Request
+        parent = "parent-995424086"
+        collection_id = "collectionId-821242276"
+        document = {}
+
+        response = client.create_document(parent, collection_id, "documentid", document)
+        assert expected_response == response
+
+        assert len(channel.requests) == 1
+        expected_request = firestore_pb2.CreateDocumentRequest(
+            parent=parent,
+            collection_id=collection_id,
+            document_id="documentid",
+            document=document,
+        )
+        actual_request = channel.requests[0][1]
+        assert expected_request == actual_request
+
+    def test_create_document_exception(self):
+        # Mock the API response
+        channel = ChannelStub(responses=[CustomException()])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup request
+        parent = "parent-995424086"
+        collection_id = "collectionId-821242276"
+        document = {}
+
+        with pytest.raises(CustomException):
+            client.create_document(parent, collection_id, "documentid", document)
+
+    def test_update_document(self):
+        # Setup Expected Response
+        name = "name3373707"
+        expected_response = {"name": name}
+        expected_response = document_pb2.Document(**expected_response)
+
+        # Mock the API response
+        channel = ChannelStub(responses=[expected_response])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup Request
+        document = {}
+
+        response = client.update_document(document)
+        assert expected_response == response
+
+        assert len(channel.requests) == 1
+        expected_request = firestore_pb2.UpdateDocumentRequest(document=document)
+        actual_request = channel.requests[0][1]
+        assert expected_request == actual_request
+
+    def test_update_document_exception(self):
+        # Mock the API response
+        channel = ChannelStub(responses=[CustomException()])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup request
+        document = {}
+
+        with pytest.raises(CustomException):
+            client.update_document(document)
+
+    def test_commit(self):
+        # Setup Expected Response
+        expected_response = {}
+        expected_response = firestore_pb2.CommitResponse(**expected_response)
+
+        # Mock the API response
+        channel = ChannelStub(responses=[expected_response])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup Request
+        database = "database1789464955"
+
+        response = client.commit(database)
+        assert expected_response == response
+
+        assert len(channel.requests) == 1
+        expected_request = firestore_pb2.CommitRequest(database=database)
+        actual_request = channel.requests[0][1]
+        assert expected_request == actual_request
+
+    def test_commit_exception(self):
+        # Mock the API response
+        channel = ChannelStub(responses=[CustomException()])
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = firestore_client.FirestoreClient()
+
+        # Setup request
+        database = "database1789464955"
+
+        with pytest.raises(CustomException):
+            client.commit(database)
